@@ -1,9 +1,9 @@
-;;; -*- Emacs-Lisp -*-
-;;; YaTeX facilities for Emacs 19 or later
-;;; (c)1994-2009 by HIROSE Yuuji.[yuuji@yatex.org]
-;;; Last modified Mon Sep 28 10:45:30 2009 on firestorm
-;;; $Id: yatex19.el,v 1.74 2009/09/28 01:54:43 yuuji Rel $
+;;; yatex19.el -- YaTeX facilities for Emacs 19 or later -*- coding: sjis -*-
+;;; (c)1994-2017 by HIROSE Yuuji.[yuuji@yatex.org]
+;;; Last modified Sun Sep 17 10:22:54 2017 on firestorm
+;;; $Id: yatex19.el,v 9c857ce72a03 2017-09-11 14:44 +0859 yuuji $
 
+;;; Code:
 ;(require 'yatex)
 
 (and (boundp 'YaTeX-use-hilit19)
@@ -15,10 +15,10 @@
 (defvar YaTeX-background-mode
   (or (if (fboundp 'get-frame-background-mode)
           (get-frame-background-mode (selected-frame)))
-      (if (fboundp 'frame-parameters)
-          (cdr (assq 'background-mode (frame-parameters))))
       (if (boundp 'frame-background-mode)
           frame-background-mode)
+      (if (fboundp 'frame-parameters)
+          (cdr (assq 'background-mode (frame-parameters))))
       (if (boundp 'hilit-background-mode)
           hilit-background-mode)
       (if (face-background 'default)
@@ -39,6 +39,7 @@
  'YaTeX-mode-menu-map-process
  (nreverse
  '((buffer "LaTeX" . (lambda () (interactive) (YaTeX-typeset-menu nil ?j)))
+   (pdf "LaTeX+PDF" . (lambda () (interactive) (YaTeX-typeset-menu nil ?d)))
    (kill "Kill LaTeX" . (lambda () (interactive) (YaTeX-typeset-menu nil ?k)))
    (bibtex "BibTeX" . (lambda () (interactive) (YaTeX-typeset-menu nil ?b)))
    (mindex "makeindex" . (lambda () (interactive) (YaTeX-typeset-menu nil ?i)))
@@ -53,11 +54,11 @@
 	(list
 	 (if YaTeX-auto-math-mode nil
 	   (cons 'math (cons "Toggle math-mode"
-			     '(lambda () (interactive)
-				(YaTeX-switch-mode-menu nil ?t)))))
+			     (function(lambda () (interactive)
+				(YaTeX-switch-mode-menu nil ?t))))))
 	 (cons 'mod (cons "Toggle Modify Mode"
-			  '(lambda () (interactive)
-			     (YaTeX-switch-mode-menu nil ?m))))))))
+			  (function(lambda () (interactive)
+			     (YaTeX-switch-mode-menu nil ?m)))))))))
 (defvar YaTeX-mode-menu-map-percent (make-sparse-keymap "percent"))
 (YaTeX-define-menu
  'YaTeX-mode-menu-map-percent
@@ -226,11 +227,12 @@
 
 (and (featurep 'xemacs)
      (add-hook 'yatex-mode-hook
-	       '(lambda ()
+	       (function
+		(lambda ()
 		  (or (assoc "YaTeX" current-menubar)
 		      (progn
 			(set-buffer-menubar (copy-sequence current-menubar))
-			(add-submenu nil YaTeX-mode-menu-map))))))
+			(add-submenu nil YaTeX-mode-menu-map)))))))
 
 ;; Other key bindings for window-system
 ;(YaTeX-define-key [?\C- ] 'YaTeX-do-completion)
@@ -482,6 +484,14 @@ towards to lowest sectioning unit.  Numbers should be written in percentage.")
 
 (defun YaTeX-19-create-face (sym fgcolor &optional bgcolor)
   "Create face named SYM with face of FGCOLOR/BGCOLOR."
+  (if (consp fgcolor)
+      (setq fgcolor (if (eq YaTeX-background-mode 'light)
+			(car fgcolor)
+		      (cdr fgcolor))))
+  (if (consp bgcolor)
+      (setq bgcolor (if (eq YaTeX-background-mode 'light)
+			(car bgcolor)
+		      (cdr bgcolor))))
   (cond
    ((and YaTeX-use-font-lock (fboundp 'defface))
     (custom-declare-face
@@ -630,7 +640,8 @@ towards to lowest sectioning unit.  Numbers should be written in percentage.")
 		    (if single (list single 0 'macro))))))))))
 
 ;;2006/6/23 new face, `delimiter' introduced
-(YaTeX-19-create-face 'delimiter "saddlebrown" "ivory")
+(YaTeX-19-create-face
+ 'delimiter '("saddlebrown" . "lightyellow") '("ivory". "navy"))
 
 ;;(YaTeX-19-collect-macros)	;causes an error
 (defun YaTeX-hilit-setup-alist ()
@@ -812,5 +823,4 @@ WARNING, This code is not perfect."
 ; fill-prefix: ";;; "
 ; paragraph-start: "^$\\|\\|;;;$"
 ; paragraph-separate: "^$\\|\\|;;;$"
-; coding: sjis
 ; End:
