@@ -1,8 +1,9 @@
-;;; -*- Emacs-Lisp -*-
-;;; Sample startup file to invoke yatex-mode with outline-minor mode.
-;;; (c )1993 by HIROSE Yuuji [yuuji@yatex.org]
-;;; Last modified Thu Aug 26 18:16:00 1999 on firestorm
+;;; yatexm-o.el --- Sample to invoke yatex-mode with outline-minor mode
 
+;;; (c)1993 by HIROSE Yuuji [yuuji@yatex.org]
+;;; Last modified Sun Dec 21 14:15:47 2014 on firestorm
+
+;;; Code:
 ;;;
 ;; outline-minor-mode(gpȂꍇ͕svł)
 ;;; 
@@ -25,12 +26,14 @@
 (autoload 'yatex-mode "yatex" "Yet Another LaTeX mode" t)
 ;;min-outgpȂꍇA;;@ ̍s͕svłB
 (defvar yatex-mode-hook
-  '(lambda ()
+  (function
+   (lambda ()
      (setq outline-regexp LaTeX-outline-regexp)			    ;;@
      (outline-minor-mode 1)					    ;;@
-     ))
+     )))
 (defvar yatex-mode-load-hook
-  '(lambda ()
+  (function
+   (lambda ()
      (setq-default outline-prefix-char (concat YaTeX-prefix "\C-o"));;@
      (require 'min-out)						    ;;@
      ;;auctex t min-out.el ̏ꍇꁫ
@@ -38,4 +41,4 @@
      ;;Emacs t outline.el ̏ꍇꁫ
      (define-key outline-mode-prefix-map "\C-?" 'hide-subtree)
      (YaTeX-define-begend-key "ba" "abstract")
-     ))
+     )))
