@@ -1,8 +1,8 @@
 ;;; yatexprc.el --- YaTeX process handler -*- coding: sjis -*-
 ;;; 
-;;; (c)1993-2018 by HIROSE Yuuji.[yuuji@yatex.org]
-;;; Last modified Wed May 30 08:32:30 2018 on firestorm
-;;; $Id: yatexprc.el,v a58a35eac93f 2018-07-31 08:21 +0900 yuuji $
+;;; (c)1993-2019 by HIROSE Yuuji.[yuuji@yatex.org]
+;;; Last modified Thu Dec 26 12:48:12 2019 on firestorm
+;;; $Id: yatexprc.el,v 4dad5f91b26c 2019-12-26 12:50 +0859 yuuji $
 
 ;;; Code:
 ;(require 'yatex)
@@ -168,6 +168,8 @@ thus, it call bibtex only if warning messages about citation are seen.")
 (defvar YaTeX-typeset-rerun-msg "Rerun to get cross-references right.")
 (defvar YaTeX-typeset-citation-msg
   "Warning: Citation \`")
+(defvar YaTeX-typeset-remove-dvi-when-pdf t
+  "*Non-nil means removing dvi file which has same rootname as PDF output")
 (defun YaTeX-typeset-sentinel (proc mes)
   (cond ((null (buffer-name (process-buffer proc)))
          ;; buffer killed
@@ -303,12 +305,22 @@ thus, it call bibtex only if warning messages about citation are seen.")
 			 (if (save-excursion
 			       (re-search-backward
 				(concat
-				 "^Output written on .*\\.pdf (.*page,"
-				 "\\|\\.dvi -> .*\\.pdf$")
+				 "^Output written on \\(.*\\.pdf\\) (.*page,"
+				 "\\|.* -> \\(.*\\.pdf\\)$")
 				nil t))
-			     ;; If PDF output log found in buffer,
-			     ;; set next default previewer to 'pdf viewer
-			     (put 'dvi2-command 'format 'pdf))
+			     (let*((pdf (or (YaTeX-match-string 1)
+					    (YaTeX-match-string 2)))
+				   (rootname (substring
+					      pdf 0 (rindex pdf ?.)))
+				   (dvi (format "%s.dvi" rootname))
+				   (log (format "%s.log" rootname)))
+			       ;; If PDF output log found in buffer,
+			       ;; set next default previewer to 'pdf viewer
+			       (put 'dvi2-command 'format 'pdf)
+			       (if YaTeX-typeset-remove-dvi-when-pdf
+				   (progn
+				     (delete-file log) ;Ugly, should not do here
+				     (delete-file dvi)))))
 		       ;;Confirm process buffer to be shown when error
 		       (YaTeX-showup-buffer
 			pbuf 'YaTeX-showup-buffer-bottom-most)
@@ -1341,6 +1353,8 @@ error or warning lines in reverse order."
        (setq fname (substring fname 0 (rindex fname ?.))))
      ext)))
 
+(defvar YaTeX-proc-feed-relative t
+  "Non-nil means feed process relative path name of target file.")
 (defun YaTeX-get-latex-command (&optional switch)
   "Specify the latex-command name and its argument.
 If there is a line which begins with string: \"%#!\", the following
@@ -1360,7 +1374,9 @@ will be given to the shell."
 	  (cond
 	   (YaTeX-parent-file
 	    (if YaTeX-dos (expand-file-name YaTeX-parent-file)
-	      YaTeX-parent-file))
+	      (if YaTeX-proc-feed-relative
+		  (file-relative-name YaTeX-parent-file)
+		YaTeX-parent-file)))
 	   (t (save-excursion
 		(YaTeX-visit-main t)
 		(file-name-nondirectory (buffer-file-name)))))
